@@ -1,3 +1,5 @@
+# vim: ts=8:sts=8:sw=8:noexpandtab
+
 # This file is part of ReText
 # Copyright: 2012-2014 Dmitry Shachnev
 #
@@ -21,29 +23,15 @@ from os.path import dirname, exists, join
 from PyQt5.QtCore import QByteArray, QLocale, QSettings, QStandardPaths
 from PyQt5.QtGui import QFont
 
-app_version = "5.3.0"
+app_version = "6.0.0"
 
 settings = QSettings('ReText project', 'ReText')
-print('Using configuration file:', settings.fileName())
 
 if not str(settings.fileName()).endswith('.conf'):
 	# We are on Windows probably
 	settings = QSettings(QSettings.IniFormat, QSettings.UserScope,
 		'ReText project', 'ReText')
 
-try:
-	import enchant
-	import enchant.errors
-except ImportError:
-	enchant_available = False
-	enchant = None
-else:
-	enchant_available = True
-	try:
-		enchant.Dict()
-	except enchant.errors.Error:
-		enchant_available = False
-
 datadirs = QStandardPaths.standardLocations(QStandardPaths.GenericDataLocation)
 datadirs = [join(d, 'retext') for d in datadirs]
 
@@ -61,23 +49,23 @@ configOptions = {
 	'autoSave': False,
 	'defaultCodec': '',
 	'defaultMarkup': '',
-	'editorFont': QFont('monospace'),
+	'editorFont': QFont(),
 	'font': QFont(),
 	'handleWebLinks': False,
 	'hideToolBar': False,
 	'highlightCurrentLine': False,
 	'iconTheme': '',
 	'lineNumbersEnabled': False,
+	'livePreviewByDefault': False,
 	'markdownDefaultFileExtension': '.mkd',
-	'previewState': False,
 	'pygmentsStyle': 'default',
 	'restDefaultFileExtension': '.rst',
-	'restorePreviewState': False,
 	'rightMargin': 0,
 	'saveWindowGeometry': False,
 	'spellCheck': False,
 	'spellCheckLocale': '',
 	'styleSheet': '',
+	'syncScroll': True,
 	'tabInsertsSpaces': True,
 	'tabWidth': 4,
 	'uiLanguage': QLocale.system().name(),
@@ -130,6 +118,11 @@ def writeListToSettings(key, value, settings=settings):
 	else:
 		settings.remove(key)
 
+def chooseMonospaceFont():
+	font = QFont('monospace')
+	font.setStyleHint(QFont.TypeWriter)
+	return font
+
 class ReTextSettings(object):
 	def __init__(self):
 		for option in configOptions:
@@ -143,6 +136,14 @@ class ReTextSettings(object):
 		object.__setattr__(self, option, value)
 		writeToSettings(option, value, configOptions[option])
 
+	def __getattribute__(self, option):
+		value = object.__getattribute__(self, option)
+		# Choose a font just-in-time, because when the settings are
+		# loaded it is too early to work on Windows
+		if option == 'editorFont' and not value.family():
+			value = chooseMonospaceFont()
+		return value
+
 globalSettings = ReTextSettings()
 
 markups.common.PYGMENTS_STYLE = globalSettings.pygmentsStyle
